# LTOP

ltop is a versatile tool for SREs and DevOps to monitor system resources and log resource utilization.

## Installation

Install ltop with pip:


        pip install ltop


Or, by downloading this repository and running:

        python3 setup.py install


## Usage

Start the system monitor:

        sudo systemctl start ltop

Stop the system monitor:

        sudo systemctl stop ltop

Restart the system monitor:

        sudo systemctl restart ltop
        
Check the status of the system monitor:

        sudo systemctl status ltop


